@@ -26,22 +26,25 @@ from snakeoil.klass import jit_attr
 from snakeoil.mappings import OrderedFrozenSet, OrderedSet
 from snakeoil.osutils import pjoin
 
-from .. import git
+from .. import cli, git
 from ..mangle import GentooMangler, Mangler
 from .argparsers import cwd_repo_argparser, git_repo_argparser
 
 
-class ArgumentParser(arghparse.ArgumentParser):
+class ArgumentParser(cli.ArgumentParser):
     """Parse all known arguments, passing unknown arguments to ``git commit``."""
 
     def parse_known_args(self, args=None, namespace=None):
         namespace.footer = OrderedSet()
         namespace.git_add_files = []
         namespace, args = super().parse_known_args(args, namespace)
+
         if namespace.dry_run:
             args.append('--dry-run')
         if namespace.verbosity:
             args.append('-v')
+        if namespace.signoff:
+            args.append('--signoff')
         namespace.commit_args = args
         return namespace, []
 
@@ -102,7 +105,7 @@ commit_opts.add_argument(
         out if any failures are found.
     """)
 commit_opts.add_argument(
-    '-A', '--ask', action='store_true',
+    '-A', '--ask', nargs='?', const=True, action=arghparse.StoreBool,
     help='confirm creating commit with QA errors',
     docs="""
         When running with the -s/--scan option enabled, ``pkgdev commit`` will
@@ -119,6 +122,17 @@ commit_opts.add_argument(
         This is performed by default for the gentoo repo, but can be forcibly
         disabled or enabled as required.
     """)
+commit_opts.add_argument(
+    '--signoff', nargs='?', const=True, action=arghparse.StoreBool,
+    help='Add a Signed-off-by at the end of the commit log message',
+    docs="""
+        Add a Signed-off-by trailer by the committer at the end of the commit
+        log message.
+
+        For commiting to the Gentoo repository, under GLEP-76, the commiter
+        shall certify agreement to the Certificate of Origin by adding
+        Signed-off-by line containing the committer's legal name.
+    """)
 
 msg_actions = commit_opts.add_mutually_exclusive_group()
 msg_actions.add_argument(
@@ -317,7 +331,10 @@ class PkgSummary(ChangeSummary):
     def add(self):
         """Generate summaries for add actions."""
         if len(self.existing) == len(self.changes):
-            return 'initial import'
+            msg = f"new package, add {', '.join(self.versions)}"
+            if len(self.versions) == 1 or len(msg) <= 50:
+                return msg
+            return 'new package'
         elif not self.revbump:
             msg = f"add {', '.join(self.versions)}"
             if len(self.versions) == 1 or len(msg) <= 50:
@@ -378,13 +395,18 @@ class PkgSummary(ChangeSummary):
             if old_pkg.eapi in new_pkg.eapi.inherits[1:]:
                 return f'update EAPI {old_pkg.eapi} -> {new_pkg.eapi}'
             elif new_pkg.keywords != old_pkg.keywords:
+                repo_stable = set(self.repo.config.arches_desc['stable'])
                 new_keywords = set(new_pkg.keywords)
                 old_keywords = set(old_pkg.keywords)
                 added = new_keywords - old_keywords
                 removed = old_keywords - new_keywords
                 if removed == {f'~{x}' for x in added}:
                     action = f'stabilize {atom.fullver}'
-                    msg = f"{action} for {', '.join(sorted(added))}"
+                    if (new_pkg.stabilize_allarches and repo_stable and
+                            not repo_stable.intersection(x.lstrip('~') for x in new_keywords - removed if x[0] == '~')):
+                        msg = f"{action} for ALLARCHES"
+                    else:
+                        msg = f"{action} for {', '.join(sorted(added))}"
                 elif removed == {x.lstrip('~') for x in added}:
                     action = f'destabilize {atom.fullver}'
                     msg = f"{action} for {', '.join(sorted(added))}"
@@ -712,9 +734,8 @@ def _commit_validate(parser, namespace):
         namespace.scan_args.extend(shlex.split(namespace.pkgcheck_scan))
     namespace.scan_args.extend(['--exit', 'GentooCI', '--staged'])
 
-    # assume signed commits means also requiring signoffs
     if namespace.repo.config.sign_commits:
-        namespace.commit_args.extend(['--signoff', '--gpg-sign'])
+        namespace.commit_args.append('--gpg-sign')
 
 
 def update_manifests(options, out, err, changes):
