@@ -7,7 +7,7 @@ from io import StringIO
 from unittest.mock import patch
 
 import pytest
-from pkgdev.mangle import copyright_regex
+from pkgdev.mangle import copyright_regex, keywords_regex
 from pkgdev.scripts import run
 from snakeoil.contexts import chdir, os_environ
 from snakeoil.osutils import pjoin
@@ -58,11 +58,19 @@ class TestPkgdevCommitParseArgs:
             options, _ = tool.parse_args(['commit', '-u'])
             assert '--signoff' not in options.commit_args
             assert '--gpg-sign' not in options.commit_args
+
+            options, _ = tool.parse_args(['commit', '-u', '--signoff'])
+            assert '--signoff' in options.commit_args
+            assert '--gpg-sign' not in options.commit_args
         # signed commits enabled by layout.conf setting
         with open(pjoin(git_repo.path, 'metadata/layout.conf'), 'a+') as f:
             f.write('sign-commits = true\n')
         with chdir(repo.location):
             options, _ = tool.parse_args(['commit', '-u'])
+            assert '--signoff' not in options.commit_args
+            assert '--gpg-sign' in options.commit_args
+
+            options, _ = tool.parse_args(['commit', '-u', '--signoff'])
             assert '--signoff' in options.commit_args
             assert '--gpg-sign' in options.commit_args
 
@@ -167,7 +175,7 @@ class TestPkgdevCommit:
         self.cache_dir = str(tmp_path)
         self.scan_args = ['--pkgcheck-scan', f'--config no --cache-dir {self.cache_dir}']
         # args for running pkgdev like a script
-        self.args = ['pkgdev', 'commit'] + self.scan_args
+        self.args = ['pkgdev', 'commit', '--config', 'no'] + self.scan_args
 
     def test_empty_repo(self, capsys, repo, make_git_repo):
         git_repo = make_git_repo(repo.location, commit=True)
@@ -425,7 +433,12 @@ class TestPkgdevCommit:
 
         # initial package import
         repo.create_ebuild('cat/newpkg-0')
-        assert commit() == 'cat/newpkg: initial import'
+        assert commit() == 'cat/newpkg: new package, add 0'
+
+        # initial package import, overflowed title truncated
+        for i in range(10):
+            repo.create_ebuild(f'cat/newpkg2-{i}.0.0')
+        assert commit() == 'cat/newpkg2: new package'
 
         # single addition
         repo.create_ebuild('cat/pkg-1')
@@ -449,28 +462,41 @@ class TestPkgdevCommit:
         )
         assert commit() == 'cat/pkg: add 5, drop 4'
 
-        # keyword version
-        repo.create_ebuild('cat/pkg-6')
-        git_repo.add_all('cat/pkg-6')
-        repo.create_ebuild('cat/pkg-6', keywords=['~amd64'])
-        assert commit() == 'cat/pkg: keyword 6 for ~amd64'
-
-        # stabilize version
-        repo.create_ebuild('cat/pkg-6', keywords=['amd64'])
-        assert commit() == 'cat/pkg: stabilize 6 for amd64'
-
-        # destabilize version
-        repo.create_ebuild('cat/pkg-6', keywords=['~amd64'])
-        assert commit() == 'cat/pkg: destabilize 6 for ~amd64'
-
-        # unkeyword version
-        repo.create_ebuild('cat/pkg-6', eapi='6')
-        assert commit() == 'cat/pkg: unkeyword 6 for ~amd64'
-
         # bump EAPI
+        repo.create_ebuild('cat/pkg-6', eapi='6')
+        git_repo.add_all('cat/pkg-6')
         repo.create_ebuild('cat/pkg-6', eapi='7')
         assert commit() == 'cat/pkg: update EAPI 6 -> 7'
 
+        # update description
+        repo.create_ebuild('cat/pkg-7')
+        git_repo.add_all('cat/pkg-7')
+        repo.create_ebuild('cat/pkg-7', description='something')
+        assert commit() == 'cat/pkg: update DESCRIPTION'
+
+        # update description & homepage
+        repo.create_ebuild('cat/pkg-7', description='another something', homepage='https://gentoo.org')
+        assert commit() == 'cat/pkg: update DESCRIPTION, HOMEPAGE'
+
+        # update string_targets (USE_RUBY)
+        repo.create_ebuild('cat/pkg-8', use_ruby='ruby27')
+        git_repo.add_all('cat/pkg-8')
+        repo.create_ebuild('cat/pkg-8', use_ruby='ruby27 ruby30')
+        assert commit() == 'cat/pkg: enable ruby30'
+        repo.create_ebuild('cat/pkg-8', use_ruby='ruby30')
+        assert commit() == 'cat/pkg: disable ruby27'
+        repo.create_ebuild('cat/pkg-8', use_ruby=' '.join(f'ruby{i}' for i in range(30, 40)))
+        assert commit() == 'cat/pkg: update USE_RUBY support'
+
+        # update array_targets (PYTHON_COMPAT)
+        repo.create_ebuild('cat/pkg-9', data='PYTHON_COMPAT=( python3_9 )')
+        git_repo.add_all('cat/pkg-9')
+        repo.create_ebuild('cat/pkg-9', data='PYTHON_COMPAT=( python3_{9..10} )')
+        assert commit() == 'cat/pkg: enable py3.10'
+        repo.create_ebuild('cat/pkg-9', data='PYTHON_COMPAT=( python3_10 )')
+        assert commit() == 'cat/pkg: disable py3.9'
+
+
         # multiple ebuild modifications don't get a generated summary
         repo.create_ebuild('cat/pkg-5', keywords=['~amd64'])
         repo.create_ebuild('cat/pkg-6', keywords=['~amd64'])
@@ -518,6 +544,74 @@ class TestPkgdevCommit:
         shutil.rmtree(pjoin(git_repo.path, 'newcat/pkg'))
         assert commit() == 'newcat/pkg: treeclean'
 
+    def test_generated_commit_summaries_keywords(self, capsys, make_repo, make_git_repo):
+        repo = make_repo(arches=['amd64', 'arm64', 'ia64', 'x86'])
+        git_repo = make_git_repo(repo.location)
+        pkgdir = os.path.dirname(repo.create_ebuild('cat/pkg-0'))
+        with open(pjoin(pkgdir, 'metadata.xml'), 'w') as f:
+            f.write(textwrap.dedent("""\
+                <?xml version="1.0" encoding="UTF-8"?>
+                <!DOCTYPE pkgmetadata SYSTEM "http://www.gentoo.org/dtd/metadata.dtd">
+                <pkgmetadata>
+                    <stabilize-allarches/>
+                </pkgmetadata>
+            """))
+        git_repo.add_all('cat/pkg-0')
+
+        def commit():
+            with os_environ(GIT_EDITOR="sed -i '1s/$/summary/'"), \
+                    patch('sys.argv', self.args + ['-a']), \
+                    pytest.raises(SystemExit) as excinfo, \
+                    chdir(git_repo.path):
+                self.script()
+            assert excinfo.value.code == 0
+            out, err = capsys.readouterr()
+            assert err == out == ''
+            message = git_repo.log(['-1', '--pretty=tformat:%B', 'HEAD'])
+            return message[0]
+
+        # keyword version
+        repo.create_ebuild('cat/pkg-0', keywords=['~amd64'])
+        assert commit() == 'cat/pkg: keyword 0 for ~amd64'
+
+        # stabilize version
+        repo.create_ebuild('cat/pkg-0', keywords=['amd64'])
+        assert commit() == 'cat/pkg: stabilize 0 for amd64'
+
+        # destabilize version
+        repo.create_ebuild('cat/pkg-0', keywords=['~amd64'])
+        assert commit() == 'cat/pkg: destabilize 0 for ~amd64'
+
+        # unkeyword version
+        repo.create_ebuild('cat/pkg-0')
+        assert commit() == 'cat/pkg: unkeyword 0 for ~amd64'
+
+        with open(pjoin(repo.location, 'profiles', 'arches.desc'), 'w') as f:
+            f.write(textwrap.dedent("""\
+                amd64 stable
+                arm64 stable
+                ia64  testing
+                x86   stable
+            """))
+        git_repo.add_all('set arches.desc')
+
+        repo.create_ebuild('cat/pkg-0', keywords=['~amd64', '~arm64', '~ia64', '~x86'])
+        git_repo.add_all('cat/pkg-0')
+
+        # stabilize version
+        repo.create_ebuild('cat/pkg-0', keywords=['amd64', '~arm64', '~ia64', '~x86'])
+        assert commit() == 'cat/pkg: stabilize 0 for amd64'
+
+        # stabilize version ALLARCHES
+        repo.create_ebuild('cat/pkg-0', keywords=['amd64', 'arm64', '~ia64', 'x86'])
+        assert commit() == 'cat/pkg: stabilize 0 for ALLARCHES'
+
+        # stabilize version
+        repo.create_ebuild('cat/newpkg-0', keywords=['~amd64', '~arm64', '~ia64', '~x86'])
+        git_repo.add_all('cat/newpkg')
+        repo.create_ebuild('cat/newpkg-0', keywords=['amd64', 'arm64', '~ia64', 'x86'])
+        assert commit() == 'cat/newpkg: stabilize 0 for amd64, arm64, x86'
+
     def test_metadata_summaries(self, capsys, repo, make_git_repo):
         git_repo = make_git_repo(repo.location)
         pkgdir = os.path.dirname(repo.create_ebuild('cat/pkg-0'))
@@ -806,8 +900,30 @@ class TestPkgdevCommit:
                 lines = f.read().splitlines()
                 mo = copyright_regex.match(lines[0])
                 assert mo.group('end') == str(datetime.today().year)
+                assert mo.group('begin') == years[:4] + '-'
                 assert mo.group('holder') == 'Gentoo Authors'
 
+        for original, expected in (
+                ('"arm64 amd64 x86"', 'amd64 arm64 x86'),
+                ('"arm64 amd64 ~x86"', 'amd64 arm64 ~x86'),
+                ('"arm64 ~x86 amd64"', 'amd64 arm64 ~x86'),
+                ('"arm64 ~x86 ~amd64"', '~amd64 arm64 ~x86'),
+                ('arm64 ~x86 ~amd64', '~amd64 arm64 ~x86'),
+                ):
+            # munge the keywords
+            with open(ebuild_path, 'r+') as f:
+                lines = f.read().splitlines()
+                lines[-1] = f'KEYWORDS={original}'
+                f.seek(0)
+                f.truncate()
+                f.write('\n'.join(lines) + '\n')
+            commit(['-n', '-u', '-m', 'mangling'])
+            # verify the keywords were updated
+            with open(ebuild_path) as f:
+                lines = f.read().splitlines()
+                mo = keywords_regex.match(lines[-1])
+                assert mo.group('keywords') == expected
+
     def test_scan(self, capsys, repo, make_git_repo):
         git_repo = make_git_repo(repo.location)
         repo.create_ebuild('cat/pkg-0')
@@ -858,6 +974,28 @@ class TestPkgdevCommit:
             self.script()
         assert excinfo.value.code == 0
 
+    def test_config_opts(self, capsys, repo, make_git_repo, tmp_path):
+        config_file = str(tmp_path / 'config')
+        with open(config_file, 'w') as f:
+            f.write(textwrap.dedent("""
+                [DEFAULT]
+                commit.scan=
+            """))
+
+        git_repo = make_git_repo(repo.location)
+        repo.create_ebuild('cat/pkg-0')
+        git_repo.add_all('cat/pkg-0')
+        repo.create_ebuild('cat/pkg-1', license='')
+        git_repo.add_all('cat/pkg-1', commit=False)
+        with patch('sys.argv', ['pkgdev', 'commit', '--config', config_file] + self.scan_args), \
+                pytest.raises(SystemExit) as excinfo, \
+                chdir(git_repo.path):
+            self.script()
+        out, err = capsys.readouterr()
+        assert excinfo.value.code == 1
+        assert not err
+        assert 'MissingLicense' in out
+
     def test_failed_manifest(self, capsys, repo, make_git_repo):
         git_repo = make_git_repo(repo.location)
         repo.create_ebuild('cat/pkg-0')
