@@ -1,4 +1,5 @@
 import os
+import sys
 import textwrap
 from datetime import datetime, timedelta, timezone
 from functools import partial
@@ -83,6 +84,18 @@ class TestPkgdevMaskParseArgs:
             options, _ = tool.parse_args(['mask', 'cat/pkg'])
         assert options.atoms == [atom_cls('cat/pkg')]
 
+    def test_email_not_rites(self, repo, make_git_repo, capsys, tool):
+        git_repo = make_git_repo(repo.location)
+
+        # masked pkg
+        repo.create_ebuild('cat/pkg-0')
+        git_repo.add_all('cat/pkg-0')
+        with pytest.raises(SystemExit), \
+                chdir(repo.location):
+            tool.parse_args(['mask', '--email', 'cat/pkg'])
+        _, err = capsys.readouterr()
+        assert err.strip() == "pkgdev mask: error: last rites required for email support"
+
 
 class TestPkgdevMask:
 
@@ -182,18 +195,80 @@ class TestPkgdevMask:
         assert self.profile.masks == frozenset([atom_cls('cat/masked'), atom_cls('=cat/pkg-0')])
 
     def test_last_rites(self):
-        with os_environ(EDITOR="sed -i '1s/$/mask comment/'"), \
-                patch('sys.argv', self.args + ['cat/pkg', '-r']), \
-                pytest.raises(SystemExit), \
-                chdir(pjoin(self.repo.path)):
-            self.script()
+        for rflag in ('-r', '--rites'):
+            for args in ([rflag], [rflag, '14']):
+                with os_environ(EDITOR="sed -i '1s/$/mask comment/'"), \
+                        patch('sys.argv', self.args + ['cat/pkg'] + args), \
+                        pytest.raises(SystemExit), \
+                        chdir(pjoin(self.repo.path)):
+                    self.script()
 
+                days = 30 if len(args) == 1 else int(args[1])
+                removal_date = self.today + timedelta(days=days)
+                today = self.today.strftime('%Y-%m-%d')
+                removal = removal_date.strftime('%Y-%m-%d')
+                assert self.masks_path.read_text() == textwrap.dedent(f"""\
+                    # First Last <first.last@email.com> ({today})
+                    # mask comment
+                    # Removal: {removal}
+                    cat/pkg
+                """)
+                self.masks_path.write_text("")  # Reset the contents of package.mask
+
+    @pytest.mark.skipif(sys.platform == "darwin", reason="no xdg-email on mac os")
+    def test_last_rites_with_email(self, tmp_path):
+        output_file = tmp_path / 'mail.txt'
+        for rflag in ('-r', '--rites'):
+            with os_environ(EDITOR="sed -i '1s/$/mask comment/'", MAILER=f"> {output_file} echo"), \
+                    patch('sys.argv', self.args + ['cat/pkg', rflag, '--email']), \
+                    pytest.raises(SystemExit), \
+                    chdir(pjoin(self.repo.path)):
+                self.script()
+            out = output_file.read_text()
+            assert 'mailto:gentoo-dev-announce@lists.gentoo.org' in out
+
+            self.masks_path.write_text("")  # Reset the contents of package.mask
+
+    @pytest.mark.skipif(sys.platform == "darwin", reason="no xdg-email on mac os")
+    def test_last_email_bad_mailer(self, capsys):
+        for rflag in ('-r', '--rites'):
+            with os_environ(EDITOR="sed -i '1s/$/mask comment/'", MAILER="false"), \
+                    patch('sys.argv', self.args + ['cat/pkg', rflag, '--email']), \
+                    pytest.raises(SystemExit), \
+                    chdir(pjoin(self.repo.path)):
+                self.script()
+            _, err = capsys.readouterr()
+            assert err.strip() == "pkgdev mask: error: failed opening email composer"
+
+    def test_mask_bugs(self):
         removal_date = self.today + timedelta(days=30)
         today = self.today.strftime('%Y-%m-%d')
         removal = removal_date.strftime('%Y-%m-%d')
-        assert self.masks_path.read_text() == textwrap.dedent(f"""\
-            # First Last <first.last@email.com> ({today})
-            # mask comment
-            # Removal: {removal}
-            cat/pkg
-        """)
+        for bflag in ('-b', '--bug'):
+            for (bug_nums, expected) in [
+                (['42'], 'Bug #42'),
+                (['42', '43'], 'Bugs #42, #43'),
+            ]:
+                args = []
+                for bug_num in bug_nums:
+                    args += [bflag, bug_num]
+                with os_environ(EDITOR="sed -i '1s/$/mask comment/'"), \
+                        patch('sys.argv', self.args + ['cat/pkg'] + args), \
+                        pytest.raises(SystemExit), \
+                        chdir(pjoin(self.repo.path)):
+                    self.script()
+
+                assert self.masks_path.read_text() == textwrap.dedent(f"""\
+                    # First Last <first.last@email.com> ({today})
+                    # mask comment
+                    # {expected}
+                    cat/pkg
+                """)
+                self.masks_path.write_text("")  # Reset the contents of package.mask
+
+    def test_mask_bug_bad(self, capsys, tool):
+        for (arg, expected) in [('-1', 'must be >= 1'), ('foo', 'invalid integer value')]:
+            with pytest.raises(SystemExit):
+                tool.parse_args(['mask', '--bug', arg])
+            out, err = capsys.readouterr()
+            assert err.strip() == f'pkgdev mask: error: argument -b/--bug: {expected}'
